"""
Enigma plugboard
"""

from __future__ import print_function

"""
RCSid:
	$Id: plugboard.py,v 1.5 2021/03/04 06:41:05 sjg Exp $

	@(#) Copyright (c) 2012 Simon J. Gerraty

	This file is provided in the hope that it will
	be of use.  There is absolutely NO WARRANTY.
	Permission to copy, redistribute or otherwise
	use this file is hereby granted provided that 
	the above copyright notice and this notice are
	left intact. 
      
	Please send copies of changes and bug-fixes to:
	sjg@crufty.net

"""

import sys

class plugboard:
    def __init__(self, pairs=[], debug=0):
        """create a bi-directional mapping for each pair of letters"""
        self.debug = debug
        self.plugged = {}
        for pair in pairs:
            pair = pair.upper()
            self.plugged[pair[0]] = pair[1]
            self.plugged[pair[1]] = pair[0]

    def transform(self, c):
        """replace c with its pair or leave as is"""
        if c in self.plugged:
            r = self.plugged[c]
            if self.debug:
                print('plug: {0} -> {1}'.format(c,r))
            return r
        return c

if __name__ == '__main__':
    import getopt

    pairs=[]
    debug=0
    opts, args = getopt.getopt(sys.argv[1:], 'dP:')
    for o, a in opts:
        if o == '-d':
            debug=1
        elif o == '-P':
            for pair in a.split(','):
                pairs.append(pair)

    
    p = plugboard(pairs, debug)


    for w in args:
        for i in range(len(w)):
            r = p.transform(w[i].upper())
            print('{0} -> {1}'.format(w[i], r))

